DatePickerHeader class

This widget displays the header for the date picker, including help text, title text, and an optional entry mode toggle button.

Inheritance

Constructors

DatePickerHeader({Key? key, required String helpText, required String titleText, String? titleSemanticsLabel, required TextStyle? titleStyle, required Orientation orientation, bool isShort = false, Widget? entryModeButton})
Creates a DatePickerHeader widget.
const

Properties

entryModeButton Widget?
An optional button to toggle the entry mode.
final
hashCode int
The hash code for this object.
no setterinherited
helpText String
The help text displayed at the top of the header.
final
isShort bool
Whether the header is in a compact layout.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
orientation Orientation
The orientation of the header (portrait or landscape).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleSemanticsLabel String?
An optional semantic label for the title text.
final
titleStyle TextStyle?
The style to apply to the title text.
final
titleText String
The title text displayed in the header.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited