InputDatePickerFormField class
A FormField that contains a InputDatePicker.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- InputDatePickerFormField
Constructors
-
InputDatePickerFormField({Key? key, NepaliDateTime? initialDate, required NepaliDateTime firstDate, required NepaliDateTime lastDate, ValueChanged<
NepaliDateTime> ? onDateSubmitted, ValueChanged<NepaliDateTime> ? onDateSaved, SelectableDayPredicate? selectableDayPredicate, String? errorFormatText, String? errorInvalidText, String? fieldHintText, String? fieldLabelText, bool autofocus = false}) -
Creates a FormField that contains a
InputDatePicker. ThefirstDatemust be on or before thelastDate. ThelastDatemust be on or after thefirstDate. TheinitialDatemust be between thefirstDateand thelastDate. IfselectableDayPredicateis non-null, it must returntruefor theinitialDate.autofocusis the initial focus state.errorFormatTextis the error text when the date is not entered in the correct format.errorInvalidTextis the error text when the date is not valid.fieldHintTextis the hint text for the input field.fieldLabelTextis the label text for the input field.onDateSubmittedis the callback when the date is submitted.onDateSavedis the callback when the date is saved.
Properties
- autofocus → bool
-
The initial focus state.
final
- errorFormatText → String?
-
The error text when the date is not entered in the correct format.
final
- errorInvalidText → String?
-
The error text when the date is not valid.
final
- fieldHintText → String?
-
The hint text for the input field.
final
- fieldLabelText → String?
-
The label text for the input field.
final
- firstDate → NepaliDateTime
-
The first date that the user can select.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDate → NepaliDateTime?
-
The initial date of the calendar.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDate → NepaliDateTime
-
The last date that the user can select.
final
-
onDateSaved
→ ValueChanged<
NepaliDateTime> ? -
The callback when the date is saved.
final
-
onDateSubmitted
→ ValueChanged<
NepaliDateTime> ? -
The callback when the date is submitted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableDayPredicate → SelectableDayPredicate?
-
Function to provide full control over which dates in the calendar can be selected.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< InputDatePickerFormField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited