syntech_nepali_calendar library

Classes

NepaliDateFormat
A class to format dates in Nepali style.
NepaliDateTime
A class to represent Nepali date and time.
NepaliMoment
A class to calculate the moment between two dates in Nepali or English.
NepaliNumberFormat
A class to format numbers in Nepali style, with support for monetary values and conversion to words in Nepali or English.
NepaliUnicode
A utility class for converting Romanized Nepali text into Nepali Unicode text.
NepaliUtils
A utility class for handling Nepali-specific functionalities.

Enums

Language
Language enum

Extensions

ENepaliDateTime on DateTime
A class to represent Nepali date and time.