NepaliDateFormat class

A class to format dates in Nepali style.

Constructors

NepaliDateFormat(String pattern, [Language? language])
Creates an instance of NepaliDateFormat.
NepaliDateFormat.d([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.E([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.EEEE([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.H([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.Hm([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.Hms([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.j([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.jm([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.jms([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.LLL([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.LLLL([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.M([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.m([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.Md([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMM([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMMd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMMEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMMM([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMMMd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.MMMMEEEEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.ms([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.QQQ([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.QQQQ([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.s([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.y([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yM([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMM([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMMd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMMEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMMM([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMMMd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yMMMMEEEEd([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yQQQ([Language? language])
Formats the given date according to the specified pattern.
NepaliDateFormat.yQQQQ([Language? language])
Formats the given date according to the specified pattern.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(NepaliDateTime date) String
Formats the given date according to the specified pattern.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseAndFormat(String dateString) String
Parses the given dateString and formats it according to the specified pattern.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited