InputDateRangePicker class
A date range picker widget in which the user can input a date range.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- InputDateRangePicker
Constructors
-
InputDateRangePicker({Key? key, NepaliDateTime? initialStartDate, NepaliDateTime? initialEndDate, required NepaliDateTime firstDate, required NepaliDateTime lastDate, required ValueChanged<
NepaliDateTime?> ? onStartDateChanged, required ValueChanged<NepaliDateTime?> ? onEndDateChanged, String? helpText, String? errorFormatText, String? errorInvalidText, String? errorInvalidRangeText, String? fieldStartHintText, String? fieldEndHintText, String? fieldStartLabelText, String? fieldEndLabelText, bool autofocus = false, bool autovalidate = false}) -
Display a InputDateRangePicker in which the user can input a date range.
The
firstDateandlastDateare required and must not be null. TheinitialStartDateandinitialEndDatedefault to null and must be betweenfirstDateandlastDate. TheonStartDateChangedandonEndDateChangedcallbacks must be provided and must not be null.
Properties
- autofocus → bool
-
The autofocus of the input field.
final
- autovalidate → bool
-
The autovalidate of the input field.
final
- errorFormatText → String?
-
The text that is displayed o qa fn the error format text.
final
- errorInvalidRangeText → String?
-
The text that is displayed on the error invalid range text.
final
- errorInvalidText → String?
-
The text that is displayed on the error invalid text.
final
- fieldEndHintText → String?
-
The text that is displayed on the end field hint text.
final
- fieldEndLabelText → String?
-
The text that is displayed on the end field label text.
final
- fieldStartHintText → String?
-
The text that is displayed on the start field hint text.
final
- fieldStartLabelText → String?
-
The text that is displayed on the start field label text.
final
- firstDate → NepaliDateTime
-
The initial date value of the start date field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpText → String?
-
The text that is displayed a help text.
final
- initialEndDate → NepaliDateTime?
-
The initial date value of the end date field.
final
- initialStartDate → NepaliDateTime?
-
The initial date value of the start date field.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDate → NepaliDateTime
-
The initial date value of the end date field.
final
-
onEndDateChanged
→ ValueChanged<
NepaliDateTime?> ? -
Called when the user changes the end date.
final
-
onStartDateChanged
→ ValueChanged<
NepaliDateTime?> ? -
Called when the user changes the start date.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< InputDateRangePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited