isSameDay function
Compare two NepaliDateTime objects to see if they are on the same day.
dateA is the first NepaliDateTime object to compare.
dateB is the second NepaliDateTime object to compare.
Returns true if the two dates are on the same day, false otherwise.
Implementation
bool isSameDay(NepaliDateTime? dateA, NepaliDateTime? dateB) {
return dateA?.year == dateB?.year &&
dateA?.month == dateB?.month &&
dateA?.day == dateB?.day;
}