NepaliDateTime class
A class to represent Nepali date and time.
- Implemented types
- Available extensions
Constructors
- NepaliDateTime(int year, [int month = 1, int day = 1, int hour = 0, int minute = 0, int second = 0, int millisecond = 0, int microsecond = 0])
- Constructs a NepaliDateTime instance.
- NepaliDateTime.fromDateTime(DateTime dateTime)
-
Constructs a NepaliDateTime instance from the given DateTime.
Returns the converted NepaliDateTime.
factory
- NepaliDateTime.now()
-
Constructs a NepaliDateTime instance from the current date and time.
factory
Properties
- day → int
-
The day of the month
[1..31].final - hashCode → int
-
The hash code for this object.
no setterinherited
- hour → int
-
The hour of the day, expressed as in a 24-hour clock
[0..23].final - isUtc → bool
-
True if this DateTime is set to UTC time.
no setteroverride
- microsecond → int
-
The microsecond
[0...999].final - microsecondsSinceEpoch → int
-
The number of microseconds since
the "Unix epoch" 1970-01-01T00:00:00Z (UTC).
no setteroverride
- millisecond → int
-
The millisecond
[0...999].final - millisecondsSinceEpoch → int
-
The number of milliseconds since
the "Unix epoch" 1970-01-01T00:00:00Z (UTC).
no setteroverride
- minute → int
-
The minute
[0...59].final - month → int
-
The month
[1..12].final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → int
-
The second
[0...59].final - timeZoneName → String
-
The time zone name.
no setteroverride
- timeZoneOffset → Duration
-
The time zone offset, which
is the difference between local time and UTC.
no setteroverride
- totalDays → int
-
Returns the total number of days in the current month.
no setter
- totalDaysInYear → int
-
Returns the total number of days in the current year.
no setter
- weekday → int
-
The day of the week monday..sunday.
no setteroverride
- year → int
-
The year.
final
Methods
-
add(
Duration duration) → NepaliDateTime -
Returns a new DateTime instance with
durationadded to this DateTime.override -
compareTo(
covariant NepaliDateTime other) → int -
Compares this DateTime object to
other, returning zero if the values are equal.override -
copyWith(
{int? year, int? month, int? day, int? hour, int? minute, int? second, int? millisecond, int? microsecond, bool? isUtc}) → DateTime -
Available on DateTime, provided by the DateTimeCopyWith extension
Creates a new DateTime from this one by updating individual properties. -
difference(
covariant NepaliDateTime other) → Duration -
Returns a Duration with the difference when subtracting
otherfrom this DateTime.override -
format(
String pattern, [Language? language]) → String - Formats the NepaliDateTime to a human-readable string.
-
isAfter(
covariant NepaliDateTime nepaliDateTime) → bool -
Whether this DateTime occurs after
other.override -
isAtSameMomentAs(
covariant NepaliDateTime other) → bool -
Whether this DateTime occurs at the same moment as
other.override -
isBefore(
covariant NepaliDateTime nepaliDateTime) → bool -
Whether this DateTime occurs before
other.override -
mergeTime(
int hour, int minute, int second) → NepaliDateTime - Returns the NepaliDateTime with the given year.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subtract(
Duration duration) → NepaliDateTime -
Returns a new DateTime instance with
durationsubtracted from this DateTime.override -
toDateTime(
) → DateTime - Returns the DateTime equivalent of the NepaliDateTime.
-
toIso8601String(
) → String -
Returns an ISO-8601 full-precision extended format representation.
override
-
toLocal(
) → NepaliDateTime -
Returns this DateTime value in the local time zone.
override
-
toNepaliDateTime(
) → NepaliDateTime -
Available on DateTime, provided by the ENepaliDateTime extension
Converts the given DateTime to NepaliDateTime. Returns the converted NepaliDateTime. -
toString(
) → String -
A string representation of this object.
override
-
toUtc(
) → DateTime -
Returns this DateTime value in the UTC time zone.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String formattedString) → NepaliDateTime -
Returns the NepaliDateTime with the given year.
override
-
tryParse(
String formattedString) → NepaliDateTime? -
Returns the NepaliDateTime with the given year.
override