NepaliNumberFormat class
A class to format numbers in Nepali style, with support for monetary values and conversion to words in Nepali or English.
Constructors
Properties
- decimalDigits → int?
-
Number of decimal digits to include.
final
- delimiter → String
-
The delimiter to use for grouping digits.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDecimalIfZero → bool
-
If true, includes decimal digits even if they are zero.
final
- inWords → bool
-
Formats the given
numberaccording to the specified options.final - isMonetory → bool
-
If true, formats the number as a monetary value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceBetweenAmountAndSymbol → bool
-
If true, adds a space between the amount and the symbol.
final
- symbol → String?
-
The monetary symbol to use.
final
- symbolOnLeft → bool
-
If true, places the symbol on the left of the number.
final
Methods
-
format<
T extends Object> (T? number) → String -
Formats the given
numberaccording to the specified options. Ifnumberisnull, returns an empty string. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited