NepaliUtils class
A utility class for handling Nepali-specific functionalities.
This class provides a singleton instance that can be configured with a specific Language. By default, it uses Language.english.
Constructors
- NepaliUtils([Language? lang])
-
Factory constructor to get the singleton instance of NepaliUtils.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ Language
-
The language used by NepaliUtils. Defaults to Language.english.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited